@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -274,11 +274,14 @@ class ReviewDocumentOperationMetadata(proto.Message):
         common_metadata (google.cloud.documentai_v1.types.CommonOperationMetadata):
             The basic metadata of the long running
             operation.
+        question_id (str):
+            The question ID.
     """
 
     common_metadata = proto.Field(
         proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
     )
+    question_id = proto.Field(proto.STRING, number=6,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
