@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -58,8 +58,7 @@ class Document(proto.Message):
         mime_type (str):
             An IANA published MIME type (also referred to
             as media type). For more information, see
-            https://www.iana.org/assignments/media-
-            types/media-types.xhtml.
+            https://www.iana.org/assignments/media-types/media-types.xhtml.
         text (str):
             UTF-8 encoded text in reading order from the
             document.
